==> ejc-bfyjerp-api-3.0.0-20250409.060850-190-sources.jar: com/ejianc/business/oa/vo/PayrollVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.oa.vo.PayrollDetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 人力行政-工资表
 * 
 * @author generator
 * 
 */
public class PayrollVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private String billCode; // 单据编号
    private BigDecimal totalSalaryMny; // 应发工资总额
    private BigDecimal totalActualSalaryMny; // 实发工资总额
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date month; // 月份
    private String memo; // 备注
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Date confirmTime; // 经办时间
    private String billStateName; // 单据状态
    
    private List<PayrollDetailVO> detailList = new ArrayList<>(); // 人力行政-工资表子表

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public BigDecimal getTotalSalaryMny() {
        return totalSalaryMny;
    }

    public void setTotalSalaryMny(BigDecimal totalSalaryMny) {
        this.totalSalaryMny = totalSalaryMny;
    }
    public BigDecimal getTotalActualSalaryMny() {
        return totalActualSalaryMny;
    }

    public void setTotalActualSalaryMny(BigDecimal totalActualSalaryMny) {
        this.totalActualSalaryMny = totalActualSalaryMny;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getConfirmTime() {
        return confirmTime;
    }

    public void setConfirmTime(Date confirmTime) {
        this.confirmTime = confirmTime;
    }

    public List<PayrollDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<PayrollDetailVO> detailList) {
        this.detailList = detailList;
    }
}

==> ejc-bfyjerp-api-3.0.0-20250926.064627-298-sources.jar: com/ejianc/business/oa/vo/PayrollVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.business.finance.vo.PayRecordVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.oa.vo.PayrollDetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 人力行政-工资表
 * 
 * @author generator
 * 
 */
public class PayrollVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private String billCode; // 单据编号
    private BigDecimal totalSalaryMny; // 应发工资总额
    private BigDecimal totalActualSalaryMny; // 实发工资总额
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date month; // 月份
    private String memo; // 备注
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Date confirmTime; // 经办时间
    private String billStateName; // 单据状态
    private BigDecimal payMny; // 支付金额
    private BigDecimal unPayMny; // 未支付金额
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date confirmTimeRecord; // 支付时间
    private List<PayRecordVO> payRecordList = new ArrayList<>();//支付记录

    public List<PayRecordVO> getPayRecordList() {
        return payRecordList;
    }

    public void setPayRecordList(List<PayRecordVO> payRecordList) {
        this.payRecordList = payRecordList;
    }
    public BigDecimal getPayMny() {
        return payMny;
    }

    public void setPayMny(BigDecimal payMny) {
        this.payMny = payMny;
    }

    public BigDecimal getUnPayMny() {
        return unPayMny;
    }

    public void setUnPayMny(BigDecimal unPayMny) {
        this.unPayMny = unPayMny;
    }

    public Date getConfirmTimeRecord() {
        return confirmTimeRecord;
    }

    public void setConfirmTimeRecord(Date confirmTimeRecord) {
        this.confirmTimeRecord = confirmTimeRecord;
    }

    private List<PayrollDetailVO> detailList = new ArrayList<>(); // 人力行政-工资表子表

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public BigDecimal getTotalSalaryMny() {
        return totalSalaryMny;
    }

    public void setTotalSalaryMny(BigDecimal totalSalaryMny) {
        this.totalSalaryMny = totalSalaryMny;
    }
    public BigDecimal getTotalActualSalaryMny() {
        return totalActualSalaryMny;
    }

    public void setTotalActualSalaryMny(BigDecimal totalActualSalaryMny) {
        this.totalActualSalaryMny = totalActualSalaryMny;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getConfirmTime() {
        return confirmTime;
    }

    public void setConfirmTime(Date confirmTime) {
        this.confirmTime = confirmTime;
    }

    public List<PayrollDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<PayrollDetailVO> detailList) {
        this.detailList = detailList;
    }
}
